@@ -1,22 +1,10 @@
 /* This file is part of the KDE project
    Copyright (C) xxxx KFile Authors
-   Copyright (C) 2002 Anders Lund <anders.lund@lund.tdcadsl.dk>
-   Copyright (C) 2007 Mirko Stocker <me@misto.ch>
-   Copyright (C) 2009 Dominik Haumann <dhaumann kde org>
+   SPDX-FileCopyrightText: 2002 Anders Lund <anders.lund@lund.tdcadsl.dk>
+   SPDX-FileCopyrightText: 2007 Mirko Stocker <me@misto.ch>
+   SPDX-FileCopyrightText: 2009 Dominik Haumann <dhaumann kde org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KATE_BOOKMARK_HANDLER_H
