@@ -21,6 +21,29 @@ bool GitUtils::isGitRepo(const QString &repo)
     return false;
 }
 
+QString GitUtils::getDotGitPath(const QString &repo)
+{
+    /* This call is intentionally blocking because we need git path for everything else */
+    QProcess git;
+    git.setProgram(QStringLiteral("git"));
+    git.setWorkingDirectory(repo);
+    git.setArguments({QStringLiteral("rev-parse"), QStringLiteral("--absolute-git-dir")});
+    git.start(QProcess::ReadOnly);
+    if (git.waitForStarted() && git.waitForFinished(-1)) {
+        if (git.exitStatus() != QProcess::NormalExit || git.exitCode() != 0) {
+            return QString();
+        }
+        QString dotGitPath = QString::fromUtf8(git.readAllStandardOutput());
+        if (dotGitPath.endsWith(QLatin1String("\n"))) {
+            dotGitPath.remove(QLatin1String(".git\n"));
+        } else {
+            dotGitPath.remove(QLatin1String(".git"));
+        }
+        return dotGitPath;
+    }
+    return QString();
+}
+
 QString GitUtils::getCurrentBranchName(const QString &repo)
 {
     // clang-format off
