@@ -118,6 +118,8 @@ public:
         /** We don't want save dialog on close */
         m_fixedView.view->document()->setModified(false);
         m_fixedView.restoreMenu();
+        /** Activate this view */
+        m_mainWindow->activateView(m_fixedView.view->document());
     }
 
     /**
@@ -222,6 +224,14 @@ Q_SIGNALS:
      */
     void message(const QVariantMap &message);
 
+    /**
+     * Signal for location changed. Location gets saved in history
+     * of the current KateViewSpace
+     * @param document url
+     * @param c pos in document
+     */
+    void addPositionToHistory(const QUrl &url, KTextEditor::Cursor c);
+
 private Q_SLOTS:
     /**
      * This slot is called whenever the active view changes in our main window.
