@@ -130,7 +130,8 @@ int main(int argc, char **argv)
                          i18n("Kate - Advanced Text Editor"),
                          KAboutLicense::LGPL_V2,
                          i18n("(c) 2000-2021 The Kate Authors"),
-                         QString(),
+                         // use the other text field to get our mascot into the about dialog
+                         QStringLiteral("<img height=\"362\" width=\"512\" src=\":/kate/mascot.png\"/>"),
                          QStringLiteral("https://kate-editor.org"));
 
     /**
